pub fn ax_wait_for_exit(task: AxTaskHandle) -> Option<i32>Expand description
Waits for the given task to exit, and returns its exit code (the
argument of ax_exit).
pub fn ax_wait_for_exit(task: AxTaskHandle) -> Option<i32>Waits for the given task to exit, and returns its exit code (the
argument of ax_exit).