pub fn ax_wait_queue_wait(
wq: &AxWaitQueueHandle,
timeout: Option<Duration>,
) -> boolExpand description
Blocks the current task and put it into the wait queue, until other tasks notify the wait queue, or the the given duration has elapsed (if specified).