pub fn ax_wait_queue_wait_until(
wq: &AxWaitQueueHandle,
until_condition: impl Fn() -> bool,
timeout: Option<Duration>,
) -> boolExpand description
Blocks the current task and put it into the wait queue, until the given condition becomes true, or the the given duration has elapsed (if specified).